@@ -1,3 +1,4 @@
 from .generation import push_generation
-from .config import get_config
+from .config import Config
 from .attribute_mapping import AttributeMapping
+from .singleton import Singleton
